@@ -3,7 +3,7 @@ package Code::TidyAll::Plugin::Go;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # ABSTRACT: Provides gofmt and go vet plugins for Code::TidyAll
 
@@ -21,7 +21,7 @@ Code::TidyAll::Plugin::Go - Provides gofmt and go vet plugins for Code::TidyAll
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -51,12 +51,16 @@ Gregory Oschwald <oschwald@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Greg Oschwald
+=for stopwords Andy Jack Dave Rolsky Greg Oschwald
 
 =over 4
 
 =item *
 
+Andy Jack <andyjack@users.noreply.github.com>
+
+=item *
+
 Dave Rolsky <drolsky@maxmind.com>
 
 =item *
