@@ -3,7 +3,7 @@ package Code::TidyAll::Plugin::Go::Vet;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Moo;
 use namespace::autoclean;
@@ -12,7 +12,7 @@ use IPC::Run3 qw( run3 );
 
 extends 'Code::TidyAll::Plugin';
 
-sub _build_cmd { 'go vet' }
+sub _build_cmd { 'go tool vet' }
 
 sub validate_file {
     my ( $self, $file ) = @_;
